@@ -8,7 +8,7 @@
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
 #
-#      http://www.apache.org/licenses/LICENSE-2.0
+# http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
@@ -20,11 +20,7 @@ import socket
 
 from oslo.config import cfg
 
-from tuskar.openstack.common import context
 from tuskar.openstack.common import log
-from tuskar.openstack.common import rpc
-from tuskar.openstack.common.rpc import service as rpc_service
-
 
 cfg.CONF.register_opts([
     cfg.IntOpt('periodic_interval',
@@ -32,7 +28,7 @@ cfg.CONF.register_opts([
                help='seconds between running periodic tasks'),
     cfg.StrOpt('host',
                default=socket.getfqdn(),
-               help='Name of this node.  This can be an opaque identifier.  '
+               help='Name of this node. This can be an opaque identifier. '
                'It is not necessarily a hostname, FQDN, or IP address. '
                'However, the node name must be valid within '
                'an AMQP key, and if using ZeroMQ, a valid '
@@ -40,18 +36,7 @@ cfg.CONF.register_opts([
 ])
 
 
-class PeriodicService(rpc_service.Service):
-
-    def start(self):
-        super(PeriodicService, self).start()
-        admin_context = context.RequestContext('admin', 'admin', is_admin=True)
-        self.tg.add_timer(cfg.CONF.periodic_interval,
-                          self.manager.periodic_tasks,
-                          context=admin_context)
-
-
 def prepare_service(argv=[]):
-    rpc.set_defaults(control_exchange='tuskar')
     cfg.set_defaults(log.log_opts,
                      default_log_levels=['amqp=WARN',
                                          'amqplib=WARN',
